import React from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';

const propTypes = {
  children: PropTypes.node.isRequired,
  /**
   * The component used for the root node.
   * Either a string to use a DOM element or a component.
   */
  tag: PropTypes.elementType,
  defaultClassName: PropTypes.oneOfType([PropTypes.string, PropTypes.arrayOf(PropTypes.string)]),
  className: PropTypes.string,
  defaultPlacement: PropTypes.string,
};

const defaultProps = {
  tag: 'div',
  defaultClassName: 'sui-prj-pipeline-job__actions',
  className: '',
  defaultPlacement: 'top',
};

export const PipelineJobActions = (props) => {
  const {
    tag: Tag,
    defaultClassName,
    className,
    defaultPlacement,
    ...attributes
  } = props;

  const classes = classnames(
    defaultClassName,
    className,
  );

  return (
    <Tag className={classes} {...attributes} />
  );
};

PipelineJobActions.propTypes = propTypes;
PipelineJobActions.defaultProps = defaultProps;
